@@ -86,7 +86,7 @@
 #define KCONTACTS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONTACTS_NO_DEPRECATED
-#  define KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KCONTACTS_NO_DEPRECATED_WARNINGS
 #  define KCONTACTS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONTACTS_DEPRECATED_WARNINGS_SINCE KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONTACTS_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KCONTACTS_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
@@ -192,7 +192,7 @@
 #define KCONTACTS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONTACTS_NO_DEPRECATED
-#  define KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KCONTACTS_NO_DEPRECATED_WARNINGS
 #  define KCONTACTS_DEPRECATED_WARNINGS_SINCE 0
@@ -202,7 +202,7 @@
 #  ifdef KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONTACTS_DEPRECATED_WARNINGS_SINCE KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONTACTS_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KCONTACTS_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
